==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/apps/rawlog-edit/rawlog-edit_list-timestamps.cpp <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

#include "rawlog-edit-declarations.h"

using namespace mrpt;
using namespace mrpt::utils;
using namespace mrpt::slam;
using namespace mrpt::system;
using namespace mrpt::rawlogtools;
using namespace std;


// ======================================================================
//		op_list_timestamps
// ======================================================================
DECLARE_OP_FUNCTION(op_list_timestamps)
{
	// A class to do this operation:
	class CRawlogProcessor_ListTimestamps : public CRawlogProcessorOnEachObservation
	{
	protected:
		string 	       m_out_file;
		std::ofstream  m_out;

	public:
		CRawlogProcessor_ListTimestamps(CFileGZInputStream &in_rawlog, TCLAP::CmdLine &cmdline, bool verbose) :
			CRawlogProcessorOnEachObservation(in_rawlog,cmdline,verbose)
		{
			getArgValue<std::string>(cmdline,"text-file-output",  m_out_file);
			VERBOSE_COUT << "Writing list to: " << m_out_file << endl;

			m_out.open(m_out_file.c_str());

			if (!m_out.is_open())
				throw std::runtime_error("list-timestamps: Cannot open output text file.");
		}

		bool processOneObservation(CObservationPtr  &obs)
		{
			m_out << std::fixed <<  mrpt::system::timestampToDouble(obs->timestamp) << " " << obs->sensorLabel << " " << obs->GetRuntimeClass()->className << std::endl;
			return true;
		}

	};

	// Process
	// ---------------------------------
	CRawlogProcessor_ListTimestamps proc(in_rawlog,cmdline,verbose);
	proc.doProcessRawlog();

	// Dump statistics:
	// ---------------------------------
	VERBOSE_COUT << "Time to process file (sec)        : " << proc.m_timToParse << "\n";

}

==> mrpt_1.3.2.orig.tar.gz: mrpt-1.3.2/apps/rawlog-edit/rawlog-edit_list-timestamps.cpp <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

#include "rawlog-edit-declarations.h"

using namespace mrpt;
using namespace mrpt::utils;
using namespace mrpt::obs;
using namespace mrpt::system;
using namespace mrpt::rawlogtools;
using namespace std;


// ======================================================================
//		op_list_timestamps
// ======================================================================
DECLARE_OP_FUNCTION(op_list_timestamps)
{
	// A class to do this operation:
	class CRawlogProcessor_ListTimestamps : public CRawlogProcessorOnEachObservation
	{
	protected:
		string 	       m_out_file;
		std::ofstream  m_out;

	public:
		CRawlogProcessor_ListTimestamps(CFileGZInputStream &in_rawlog, TCLAP::CmdLine &cmdline, bool verbose) :
			CRawlogProcessorOnEachObservation(in_rawlog,cmdline,verbose)
		{
			getArgValue<std::string>(cmdline,"text-file-output",  m_out_file);
			VERBOSE_COUT << "Writing list to: " << m_out_file << endl;

			m_out.open(m_out_file.c_str());

			if (!m_out.is_open())
				throw std::runtime_error("list-timestamps: Cannot open output text file.");
		}

		bool processOneObservation(CObservationPtr  &obs)
		{
			m_out << std::fixed <<  mrpt::system::timestampToDouble(obs->timestamp) << " " << obs->sensorLabel << " " << obs->GetRuntimeClass()->className << std::endl;
			return true;
		}

	};

	// Process
	// ---------------------------------
	CRawlogProcessor_ListTimestamps proc(in_rawlog,cmdline,verbose);
	proc.doProcessRawlog();

	// Dump statistics:
	// ---------------------------------
	VERBOSE_COUT << "Time to process file (sec)        : " << proc.m_timToParse << "\n";

}
